import env from './env';
import InitDB from './initDB';
function idbFactory() {
    /* 兼容浏览器和webworker */
    var db = indexedDB || webkitIndexedDB || mozIndexedDB || msIndexedDB;
    return db;
}
/**
 * 初始化数据库
 * @param { string } name            创建或者连接的数据库名
 * @param { number } version         数据库版本号
 * @param { object } callbackObject  配置回调函数
 *   - success                       创建或者连接的数据库成功后的回调函数
 *   - error                         创建或者连接的数据库失败后的回调函数
 *   - upgradeneeded                 数据库版本号更新后的回调函数
 */
function IndexedDB(name, version, callbackObject) {
    var db = idbFactory();
    IndexedDB.prototype.indexeddb = db;
    return new InitDB(db, name, version, callbackObject);
}
/**
 * 删除数据库
 * @param { string } databaseName: 数据库名
 */
IndexedDB.deleteDatabase = function (databaseName) {
    var db = idbFactory();
    var req = db.deleteDatabase(databaseName);
    if (env === 'development') {
        console.log("\u5220\u9664\u6570\u636E\u5E93\uFF1A" + databaseName + "\u3002");
    }
    return req;
};
export default IndexedDB;
